@@ -7,13 +7,14 @@ function tr($namespace = '') {
 
   if (strlen($namespace) > 0) {
     if (!strcmp($namespace, 'information_schema')
-      or !strcmp($namespace, 'pg_catalog')
-      or !strcmp(substr($namespace, 0, 8), 'pg_toast')) {
+      || !strcmp($namespace, 'pg_catalog')
+      || !strcmp(substr($namespace, 0, 8), 'pg_toast')) {
       $class = 'sys';
     } else {
       $class = 'usr';
     }
   }
+  else $class = '';
   if ($odd) {
     if (strlen($class) > 0) {
       $class .= '_';
@@ -26,4 +27,11 @@ function tr($namespace = '') {
   return $tr;
 }
 
-?>
\ No newline at end of file
+function add_sys_and_user_checkboxes() {
+  global $buffer;
+
+  $buffer .= '<label><input id ="showusrobjects" type="checkbox" checked>Show User Objects</label>
+<label><input id ="showsysobjects" type="checkbox" checked>Show System Objects</label>';
+}
+
+?>
